@@ -7,21 +7,16 @@ from datetime import datetime
 
 import json
 
-try:
-  from PyQt6.QtCore import Qt, QSize
-  from PyQt6.QtGui import QFont
-  from PyQt6.QtWidgets import QWidget, QButtonGroup, QCheckBox, QDialog, QFileDialog, QHBoxLayout, QApplication, QLabel, QMainWindow, QRadioButton, QStackedLayout, QVBoxLayout, QMessageBox, QTextEdit, QSpacerItem, QPushButton
-  PYQT6 = True
-except ImportError:
-  from PyQt5.QtCore import Qt, QSize
-  from PyQt5.QtGui import QFont
-  from PyQt5.QtWidgets import QWidget, QButtonGroup, QCheckBox, QDialog, QFileDialog, QHBoxLayout, QApplication, QLabel, QMainWindow, QRadioButton, QStackedLayout, QVBoxLayout, QMessageBox, QTextEdit, QSpacerItem, QPushButton
-  QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
-  QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
-  QApplication.setHighDpiScaleFactorRoundingPolicy(Qt.HighDpiScaleFactorRoundingPolicy.PassThrough)
-  PYQT6 = False
+from PyQt5.QtCore import Qt, QSize
+from PyQt5.QtGui import QFont, QIcon
+from PyQt5.QtWidgets import QWidget, QButtonGroup, QCheckBox, QDialog, QFileDialog, QHBoxLayout, QApplication, QLabel, QMainWindow, QRadioButton, QStackedLayout, QVBoxLayout, QMessageBox, QTextEdit, QSpacerItem, QPushButton
+QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
+QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+QApplication.setHighDpiScaleFactorRoundingPolicy(Qt.HighDpiScaleFactorRoundingPolicy.PassThrough)
+PYQT6 = False
 
 import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
+import zebrazoom.code.paths as paths
 import zebrazoom.code.util as util
 import zebrazoom.code.GUI.configFilePrepareFunctions as configFilePrepareFunctions
 import zebrazoom.code.GUI.GUI_InitialFunctions as GUI_InitialFunctions
@@ -53,7 +48,7 @@ def excepthook(excType, excValue, traceback_):
   errorMessage.setText("An error has ocurred: %s" % formattedTraceback[-1])
   informativeText = 'Please report the issue on <a href="https://github.com/oliviermirat/ZebraZoom/issues">Github</a>.'
   if app.configFile and app.savedConfigFile != {k: v for k, v in app.configFile.items() if k != "firstFrame" and k != "lastFrame"}:
-    configDir = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration')
+    configDir = paths.getConfigurationFolder()
     videoName = os.path.splitext(os.path.basename(app.videoToCreateConfigFileFor))[0]
     configFilename = os.path.join(configDir, '%s_%s_unfinished.json' % (videoName, datetime.now().strftime("%Y_%m_%d-%H_%M_%S")))
     with open(configFilename, 'w') as f:
@@ -80,13 +75,19 @@ def excepthook(excType, excValue, traceback_):
 sys.excepthook = excepthook
 
 
-class ZebraZoomApp(QApplication):
+class PlainApplication(QApplication):
     def __init__(self, args):
         super().__init__(args)
         if not PYQT6 and sys.platform.startswith('win'):  # qt5 uses deprecated windows API to determine the system font, this works around that issuue
             self.setFont(QApplication.font("QMessageBox"))
 
-        self.homeDirectory = os.path.dirname(os.path.realpath(__file__))
+
+class ZebraZoomApp(PlainApplication):
+    def __init__(self, args):
+        super().__init__(args)
+        self.version = '1.32.55'
+
+        self.homeDirectory = paths.getRootDataFolder()
 
         self.savedConfigFile = None
         self.configFile = {}
@@ -99,9 +100,7 @@ class ZebraZoomApp(QApplication):
 
         self.configFileHistory = []
 
-        curZZoutputPath = os.path.dirname(os.path.realpath(__file__))
-        curZZoutputPath = os.path.join(curZZoutputPath, 'ZZoutput')
-        self.ZZoutputLocation = curZZoutputPath
+        self.ZZoutputLocation = paths.getDefaultZZoutputFolder()
 
         self.title_font = QFont('Helvetica', 18, QFont.Weight.Bold, True)
 
@@ -109,6 +108,7 @@ class ZebraZoomApp(QApplication):
 
         self._windows = set()
         self.window = QMainWindow()
+        self.window.setWindowIcon(QIcon('icon.ico'))
         self.window.closeEvent = self._windowClosed(self.window, self.window.closeEvent)
         layout = QStackedLayout()
         self.frames = {}
@@ -259,18 +259,18 @@ class ZebraZoomApp(QApplication):
     def regionsOfInterest(self, controller, nbwells):
         configFilePrepareFunctions.regionsOfInterest(self, controller, nbwells)
 
-    def homegeneousWellsLayout(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
-        configFilePrepareFunctions.homegeneousWellsLayout(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows)
+    def homegeneousWellsLayout(self, controller, nbRowsOfWells, nbWellsPerRows):
+        configFilePrepareFunctions.homegeneousWellsLayout(self, controller, nbRowsOfWells, nbWellsPerRows)
 
-    def morePreciseFastScreen(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
-        configFilePrepareFunctions.morePreciseFastScreen(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows)
+    def morePreciseFastScreen(self, controller, nbRowsOfWells, nbWellsPerRows):
+        configFilePrepareFunctions.morePreciseFastScreen(self, controller, nbRowsOfWells, nbWellsPerRows)
 
     def circularOrRectangularWells(self, controller, nbRowsOfWells, nbWellsPerRows, nbanimals):
         configFilePrepareFunctions.circularOrRectangularWells(self, controller, nbRowsOfWells, nbWellsPerRows, nbanimals)
 
     def finishConfig(self, testConfig=False):
         suggestedName = '%s_%s' % (os.path.splitext(os.path.basename(self.videoToCreateConfigFileFor))[0], datetime.now().strftime("%Y_%m_%d-%H_%M_%S"))
-        configDir = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration')
+        configDir = paths.getConfigurationFolder()
         reference, _ = QFileDialog.getSaveFileName(self.window, "Save config", os.path.join(configDir, suggestedName), "JSON (*.json)")
         if not reference:
           return
