@@ -1,17 +1,15 @@
 import numpy as np
 from zebrazoom.mainZZ import mainZZ
+import os
 import pickle
 import cv2
 import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 from zebrazoom.code.GUI.adjustParameterInsideAlgo import adjustParamInsideAlgoPage, adjustBoutDetectionOnlyPage, adjustParamInsideAlgoFreelySwimPage, adjustParamInsideAlgoFreelySwimAutomaticParametersPage
 
-try:
-  from PyQt6.QtCore import Qt
-  from PyQt6.QtWidgets import QApplication, QDialog, QLabel, QPushButton, QVBoxLayout
-except ImportError:
-  from PyQt5.QtCore import Qt
-  from PyQt5.QtWidgets import QApplication, QDialog, QLabel, QPushButton, QVBoxLayout
+from PyQt5.QtCore import Qt
+from PyQt5.QtWidgets import QApplication, QDialog, QLabel, QPushButton, QVBoxLayout
 
+import zebrazoom.code.paths as paths
 import zebrazoom.code.util as util
 
 
@@ -91,7 +89,7 @@ def detectBouts(self, controller, wellNumber, firstFrame, adjustOnWholeVideo):
         del configFile["lastFrame"]
       mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
     except ValueError:
-      newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+      newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
       for index in newhyperparameters:
         configFile[index] = newhyperparameters[index]
     except NameError:
@@ -134,7 +132,7 @@ def adjustHeadEmbededTracking(self, controller, wellNumber, firstFrame, adjustOn
       del configFile["lastFrame"]
     mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
   except ValueError:
-    newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+    newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
     for index in newhyperparameters:
       configFile[index] = newhyperparameters[index]
   except NameError:
@@ -170,7 +168,7 @@ def adjustFreelySwimTracking(self, controller, wellNumber, firstFrame, adjustOnW
       del configFile["lastFrame"]
     mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
   except ValueError:
-    newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+    newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
     for index in newhyperparameters:
       configFile[index] = newhyperparameters[index]
   except NameError:
@@ -215,7 +213,7 @@ def _adjustFastFreelySwimTracking(self, controller, oldFirstFrame):
       del configFile["lastFrame"]
     mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
   except ValueError:
-    newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+    newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
     for index in newhyperparameters:
       configFile[index] = newhyperparameters[index]
   except NameError:
@@ -226,11 +224,16 @@ def _adjustFastFreelySwimTracking(self, controller, oldFirstFrame):
   del configFile["adjustFreelySwimTracking"]
 
   self.configFile = configFile
+  
+  trackingMethodOldValue = configFile["trackingMethod"]
 
   if configFile["trackTail"] == 0: # FasterMultiprocessing screen option here
 
     # The image filtering option should be added here in the future
     self.configFile = {"nbWells": 25, "nbRowsOfWells": 5, "nbWellsPerRows": 5, "minPixelDiffForBackExtract": 20, "backgroundPreProcessParameters": [[3]], "backgroundPreProcessMethod": ["erodeThenMin"], "postProcessMultipleTrajectories": 1, "postProcessRemoveLowProbabilityDetection" : 0,"postProcessLowProbabilityDetectionThreshold" : 1, "postProcessRemovePointsOnBordersMargin" : 1, "trackingPointSizeDisplay": 1, "extractAdvanceZebraParameters": 0, "groupOfMultipleSameSizeAndShapeEquallySpacedWells": 1, "nbAnimalsPerWell": 1, "trackTail": 0, "validationVideoPlotHeading": 0, "freqAlgoPosFollow": 100, "fasterMultiprocessing": 1, "copyOriginalVideoToOutputFolderForValidation": 0, "backgroundExtractionForceUseAllVideoFrames": 1}
+    
+    if len(trackingMethodOldValue):
+      self.configFile["trackingMethod"] = trackingMethodOldValue
 
     self.configFile["nbWells"]          = configFile["nbAnimalsPerWell"]
     self.configFile["nbRowsOfWells"]    = configFile["nbRowsOfWells"]
@@ -261,7 +264,7 @@ def adjustFreelySwimTrackingAutomaticParameters(self, controller, wellNumber, fi
       del configFile["lastFrame"]
     mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
   except ValueError:
-    newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+    newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
     for index in newhyperparameters:
       configFile[index] = newhyperparameters[index]
   except NameError:
@@ -298,6 +301,7 @@ def calculateBackground(self, controller, nbImagesForBackgroundCalculation, useN
 
   app = QApplication.instance()
   app.wellPositions = []
+  app.background = []
   with app.busyCursor():
     try:
       if "lastFrame" in configFile and "firstFrame" in configFile and configFile["lastFrame"] < configFile["firstFrame"]:
