@@ -1,4 +1,3 @@
-from pathlib import Path
 import numpy as np
 import cv2
 import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
@@ -9,19 +8,15 @@ from zebrazoom.code.findWells import findWells
 from zebrazoom.code.getHyperparameters import getHyperparametersSimple
 from zebrazoom.code.getBackground import getBackground
 from zebrazoom.code.getImage.getForegroundImage import getForegroundImage
-import cvui
 import pickle
 from zebrazoom.mainZZ import mainZZ
 import json
 import os
 
-try:
-  from PyQt6.QtCore import Qt, QTimer
-  from PyQt6.QtWidgets import QApplication, QFileDialog, QGridLayout, QLabel, QMessageBox, QVBoxLayout
-except ImportError:
-  from PyQt5.QtCore import Qt, QTimer
-  from PyQt5.QtWidgets import QApplication, QFileDialog, QGridLayout, QLabel, QMessageBox, QVBoxLayout
+from PyQt5.QtCore import Qt, QTimer
+from PyQt5.QtWidgets import QApplication, QFileDialog, QGridLayout, QLabel, QMessageBox, QVBoxLayout
 
+import zebrazoom.code.paths as paths
 import zebrazoom.code.util as util
 
 
@@ -42,12 +37,7 @@ def chooseVideoToCreateConfigFileFor(self, controller, reloadConfigFile):
 
   if int(reloadConfigFile):
 
-    cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-    pathconf = Path(cur_dir_path)
-    pathconf = pathconf.parent.parent
-    pathconf = os.path.join(pathconf, 'configuration/')
-
-    configFileName, _ =  QFileDialog.getOpenFileName(self.window, "Select configuration file", pathconf, "JSON (*.json)")
+    configFileName, _ =  QFileDialog.getOpenFileName(self.window, "Select configuration file", paths.getConfigurationFolder(), "JSON (*.json)")
     if not configFileName:
       return False
     try:
@@ -167,7 +157,7 @@ def rectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
     try:
       mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
     except ValueError:
-      newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+      newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
       for index in newhyperparameters:
         configFile[index] = newhyperparameters[index]
     except NameError:
@@ -181,44 +171,29 @@ def rectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
 
 
 @util.addToHistory
-def homegeneousWellsLayout(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
+def homegeneousWellsLayout(self, controller, nbRowsOfWells, nbWellsPerRows):
 
   self.configFile = {"trackingMethod": "fastCenterOfMassTracking_KNNbackgroundSubtraction", "nbAnimalsPerWell": 1, "nbWells": 8, "nbRowsOfWells": 2, "nbWellsPerRows": 4, "groupOfMultipleSameSizeAndShapeEquallySpacedWells": 1, "postProcessMultipleTrajectories": 0, "trackingPointSizeDisplay": 3, "extractAdvanceZebraParameters": 0,  "validationVideoPlotHeading": 0, "trackTail": 0, "freqAlgoPosFollow": 100, "fasterMultiprocessing": 1, "copyOriginalVideoToOutputFolderForValidation": 0, "backgroundSubtractorKNN": 1, "boutsMinNbFrames": 0, "addOneFrameAtTheEndForBoutDetection": 1, "fillGapFrameNb": 0} # "postProcessMultipleTrajectories": 1, "postProcessRemoveLowProbabilityDetection" : 1, "postProcessLowProbabilityDetectionPercentOfMaximum" : 0.2
 
-  self.configFile["nbWells"]          = int(nbwells)
-
-  if len(nbRowsOfWells):
-    self.configFile["nbRowsOfWells"]  = int(nbRowsOfWells)
-  else:
-    self.configFile["nbRowsOfWells"]  = 1
-
-  if len(nbWellsPerRows):
-    self.configFile["nbWellsPerRows"]  = int(nbWellsPerRows)
-  else:
-    self.configFile["nbWellsPerRows"]  = 4
+  self.configFile["nbWells"] = int(nbRowsOfWells) * int(nbWellsPerRows)
+  self.configFile["nbRowsOfWells"] = int(nbRowsOfWells)
+  self.configFile["nbWellsPerRows"] = int(nbWellsPerRows)
 
   controller.show_frame("FinishConfig")
 
 
 @util.addToHistory
-def morePreciseFastScreen(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
+def morePreciseFastScreen(self, controller, nbRowsOfWells, nbWellsPerRows):
 
   # The gaussian image filtering should be added here in the future
   self.configFile = {"trackingMethod": "fastCenterOfMassTracking_ClassicalBackgroundSubtraction", "minPixelDiffForBackExtract": 20, "backgroundPreProcessParameters": [[3]], "backgroundPreProcessMethod": ["erodeThenMin"], "trackingPointSizeDisplay": 1, "nbAnimalsPerWell": 1, "extractAdvanceZebraParameters": 0, "trackTail": 0, "nbWells": 1, "noWellDetection": 1, "backgroundExtractionForceUseAllVideoFrames": 1, "headSize": 2, "createValidationVideo": 0, "lastFrame": 1000}
 
-  self.configFile["nbAnimalsPerWell"] = int(nbwells)
+  self.configFile["nbAnimalsPerWell"] = int(nbRowsOfWells) * int(nbWellsPerRows)
 
   # self.configFile["nbWells"]          = int(nbwells)
 
-  if len(nbRowsOfWells):
-    self.configFile["nbRowsOfWells"]  = int(nbRowsOfWells)
-  else:
-    self.configFile["nbRowsOfWells"]  = 1
-
-  if len(nbWellsPerRows):
-    self.configFile["nbWellsPerRows"]  = int(nbWellsPerRows)
-  else:
-    self.configFile["nbWellsPerRows"]  = 4
+  self.configFile["nbRowsOfWells"] = int(nbRowsOfWells)
+  self.configFile["nbWellsPerRows"] = int(nbWellsPerRows)
 
   self.calculateBackgroundFreelySwim(controller, 0, True)
 
@@ -291,7 +266,7 @@ def _chooseEnd(self, controller):
 
 def chooseBeginningAndEndOfVideo(self, controller):
   util.chooseBeginningPage(controller, controller.videoToCreateConfigFileFor, "Choose where the analysis of your video should start.", "Ok, I want the tracking to start at this frame!", lambda: _chooseEnd(self, controller),
-                           extraButtonInfo=("I want the tracking to run on the entire video!", lambda: _beginningAndEndChosen(self, controller), {"background_color": "red"}))
+                           extraButtonInfo=("I want the tracking to run on the entire video!", lambda: _beginningAndEndChosen(self, controller), {"background_color": "greenyellow"}))
 
 
 def getImageForMultipleAnimalGUI(l, nx, ny, max_l, videoToCreateConfigFileFor, background, wellPositions, hyperparameters):
@@ -373,7 +348,6 @@ def identifyMultipleHead(self, controller, nbanimals):
     background    = getBackground(self.videoToCreateConfigFileFor, hyperparameters)
 
   cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-  cur_dir_path = Path(cur_dir_path)
 
   def imagesGenerator():
     images = (cv2.imread(os.path.join(cur_dir_path, 'no1.png')),
