@@ -1,9 +1,7 @@
-from pathlib import Path
 import numpy as np
 import json
 import cv2
 import math
-import cvui
 from zebrazoom.code.vars import getGlobalVariables
 import json
 import os
@@ -12,25 +10,15 @@ import sys
 import pandas as pd
 globalVariables = getGlobalVariables()
 
-try:
-  from PyQt6.QtWidgets import QFileDialog
-except ImportError:
-  from PyQt5.QtWidgets import QFileDialog
+from PyQt5.QtWidgets import QFileDialog
 
+import zebrazoom.code.paths as paths
 from zebrazoom.dataAnalysis.datasetcreation.createDataFrame import createDataFrame
 from zebrazoom.dataAnalysis.dataanalysis.populationComparaison import populationComparaison
 from zebrazoom.dataAnalysis.dataanalysis.applyClustering import applyClustering
 
 from zebrazoom.dataAnalysis.datasetcreation.generatePklDataFileForVideo import generatePklDataFileForVideo
 
-def openExperimentOrganizationExcelFolder(self, homeDirectory):
-  dir_path = os.path.join(homeDirectory,'dataAnalysis/experimentOrganizationExcel/')
-  if sys.platform == "win32":
-    os.startfile(dir_path)
-  else:
-    opener ="open" if sys.platform == "darwin" else "xdg-open"
-    subprocess.call([opener, dir_path])
-
 
 def openAnalysisFolder(self, homeDirectory, specificDirectory):
   dir_path = os.path.join(os.path.join(homeDirectory,'dataAnalysis'), specificDirectory)
@@ -41,23 +29,7 @@ def openAnalysisFolder(self, homeDirectory, specificDirectory):
     subprocess.call([opener, dir_path])
 
 
-def chooseExperimentOrganizationExcel(self, controller):
-
-  cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-  cur_dir_path = Path(cur_dir_path)
-  cur_dir_path = cur_dir_path.parent.parent
-
-  experimentOrganizationExcel, _ =  QFileDialog.getOpenFileName(self.window, "Select the excel file describing your experiments", os.path.join(cur_dir_path, 'dataAnalysis/experimentOrganizationExcel/'), "All files(*)")
-
-  array = os.path.split(experimentOrganizationExcel)
-
-  self.experimentOrganizationExcel = array[len(array)-1]
-  self.experimentOrganizationExcelFileAndFolder = ''.join(array[0:len(array)-1])
-
-  controller.show_frame("ChooseDataAnalysisMethod")
-
-
-def populationComparison(self, controller, TailTrackingParameters=0, saveInMatlabFormat=0, saveRawData=0, minNbBendForBoutDetect=3, discard=0, keep=1, frameStepForDistanceCalculation='4'):
+def populationComparison(self, controller, TailTrackingParameters=0, saveInMatlabFormat=0, saveRawData=0, forcePandasRecreation=0, minNbBendForBoutDetect=3, discard=0, keep=1, frameStepForDistanceCalculation='4'):
   
   if len(frameStepForDistanceCalculation) == 0:
     frameStepForDistanceCalculation = '4'
@@ -68,12 +40,8 @@ def populationComparison(self, controller, TailTrackingParameters=0, saveInMatla
   if len(minNbBendForBoutDetect) == 0:
     minNbBendForBoutDetect = 3
 
-  cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-  cur_dir_path = Path(cur_dir_path)
-  cur_dir_path = cur_dir_path.parent.parent
-
   if len(controller.ZZoutputLocation) == 0:
-    ZZoutputLocation = os.path.join(cur_dir_path, 'ZZoutput')
+    ZZoutputLocation = paths.getDefaultZZoutputFolder()
   else:
     ZZoutputLocation = controller.ZZoutputLocation
 
@@ -82,10 +50,10 @@ def populationComparison(self, controller, TailTrackingParameters=0, saveInMatla
   dataframeOptions = {
     'pathToExcelFile'                   : self.experimentOrganizationExcelFileAndFolder, #os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'experimentOrganizationExcel/')),
     'fileExtension'                     : '.' + self.experimentOrganizationExcel.split(".")[1],
-    'resFolder'                         : os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'data')),
+    'resFolder'                         : os.path.join(paths.getDataAnalysisFolder(), 'data'),
     'nameOfFile'                        : self.experimentOrganizationExcel.split(".")[0],
     'smoothingFactorDynaParam'          : 0,   # 0.001
-    'nbFramesTakenIntoAccount'          : 28,
+    'nbFramesTakenIntoAccount'          : 0,
     'numberOfBendsIncludedForMaxDetect' : -1,
     'minNbBendForBoutDetect'            : int(minNbBendForBoutDetect),
     'keepSpeedDistDurWhenLowNbBends'    : int(keep),
@@ -93,33 +61,33 @@ def populationComparison(self, controller, TailTrackingParameters=0, saveInMatla
     'computeTailAngleParamForCluster'   : False,
     'computeMassCenterParamForCluster'  : False,
     'tailAngleKinematicParameterCalculation'    : TailTrackingParameters,
-    'saveRawDataInAllBoutsSuperStructure'       : saveInMatlabFormat,
-    'saveAllBoutsSuperStructuresInMatlabFormat' : saveRawData,
+    'saveRawDataInAllBoutsSuperStructure'       : saveRawData,
+    'saveAllBoutsSuperStructuresInMatlabFormat' : saveInMatlabFormat,
     'frameStepForDistanceCalculation'           : frameStepForDistanceCalculation
   }
   
-  generatePklDataFileForVideo(os.path.join(self.experimentOrganizationExcelFileAndFolder, self.experimentOrganizationExcel), ZZoutputLocation, frameStepForDistanceCalculation)
+  generatePklDataFileForVideo(os.path.join(self.experimentOrganizationExcelFileAndFolder, self.experimentOrganizationExcel), ZZoutputLocation, frameStepForDistanceCalculation, forcePandasRecreation)
   
-  [conditions, genotypes, nbFramesTakenIntoAccount, globParam] = createDataFrame(dataframeOptions, "", 0, ['BoutFrameNumberStart', 'tailAngleSymmetry', 'secondBendAmpDividedByFirst', 'tailAngleIntegral'])
+  [conditions, genotypes, nbFramesTakenIntoAccount, globParam] = createDataFrame(dataframeOptions, "", forcePandasRecreation, [])
   
   # Plotting for the different conditions
   nameOfFile = dataframeOptions['nameOfFile']
   resFolder  = dataframeOptions['resFolder']
 
   # Mixing up all the bouts
-  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'resultsKinematic')), 0, True)
+  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(paths.getDataAnalysisFolder(), 'resultsKinematic'), 0, True)
 
-  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'resultsKinematic')), 0, False)
+  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(paths.getDataAnalysisFolder(), 'resultsKinematic'), 0, False)
 
   # First median per well for each kinematic parameter
-  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'resultsKinematic')), 1, True)
+  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(paths.getDataAnalysisFolder(), 'resultsKinematic'), 1, True)
 
-  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'resultsKinematic')), 1, False)
+  populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, os.path.join(paths.getDataAnalysisFolder(), 'resultsKinematic'), 1, False)
 
   controller.show_frame("AnalysisOutputFolderPopulation")
 
 
-def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbeded, minNbBendForBoutDetect=3, nbVideosToSave=0, modelUsedForClustering=0, removeOutliers=False, frameStepForDistanceCalculation='4'):
+def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbeded, minNbBendForBoutDetect=3, nbVideosToSave=0, modelUsedForClustering=0, removeOutliers=False, frameStepForDistanceCalculation='4', removeBoutsContainingNanValuesInParametersUsedForClustering=True, forcePandasRecreation=0):
 
   if len(frameStepForDistanceCalculation) == 0:
     frameStepForDistanceCalculation = '4'
@@ -141,12 +109,9 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
 
   videoSaveFirstTenBouts = True if nbVideosToSave else False
 
-  cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-  cur_dir_path = Path(cur_dir_path)
-  cur_dir_path = cur_dir_path.parent.parent
 
   if len(controller.ZZoutputLocation) == 0:
-    ZZoutputLocation = os.path.join(cur_dir_path, 'ZZoutput')
+    ZZoutputLocation = paths.getDefaultZZoutputFolder()
   else:
     ZZoutputLocation = controller.ZZoutputLocation
 
@@ -154,7 +119,7 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
   dataframeOptions = {
     'pathToExcelFile'                   : self.experimentOrganizationExcelFileAndFolder, # os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'experimentOrganizationExcel')),
     'fileExtension'                     : '.' + self.experimentOrganizationExcel.split(".")[1],
-    'resFolder'                         : os.path.join(cur_dir_path, os.path.join('dataAnalysis', 'data')),
+    'resFolder'                         : os.path.join(paths.getDataAnalysisFolder(), 'data'),
     'nameOfFile'                        : self.experimentOrganizationExcel.split(".")[0],
     'smoothingFactorDynaParam'          : 0,   # 0.001
     'nbFramesTakenIntoAccount'          : -1, #28,
@@ -169,9 +134,9 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
   if int(FreelySwimming):
     dataframeOptions['computeMassCenterParamForCluster'] = True
     
-  generatePklDataFileForVideo(os.path.join(self.experimentOrganizationExcelFileAndFolder, self.experimentOrganizationExcel), ZZoutputLocation, frameStepForDistanceCalculation)
+  generatePklDataFileForVideo(os.path.join(self.experimentOrganizationExcelFileAndFolder, self.experimentOrganizationExcel), ZZoutputLocation, frameStepForDistanceCalculation, forcePandasRecreation)
     
-  [conditions, genotypes, nbFramesTakenIntoAccount, globParam] = createDataFrame(dataframeOptions, "", 0, ['BoutFrameNumberStart', 'tailAngleSymmetry', 'secondBendAmpDividedByFirst', 'tailAngleIntegral'])
+  [conditions, genotypes, nbFramesTakenIntoAccount, globParam] = createDataFrame(dataframeOptions, "", forcePandasRecreation, [])
   # Applying the clustering on this dataframe
   clusteringOptions = {
     'analyzeAllWellsAtTheSameTime' : 0, # put this to 1 for head-embedded videos, and to 0 for multi-well videos
@@ -192,10 +157,11 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
     'videoSaveFirstTenBouts' : videoSaveFirstTenBouts,
     'globalParametersCalculations' : True,
     'nbVideosToSave' : nbVideosToSave,
-    'resFolder' : os.path.join(os.path.join(cur_dir_path, 'dataAnalysis'),'data/'),
+    'resFolder' : os.path.join(paths.getDataAnalysisFolder(), 'data/'),
     'nameOfFile' : self.experimentOrganizationExcel.split(".")[0],
     'modelUsedForClustering' : modelUsedForClustering,
-    'removeOutliers'         : removeOutliers
+    'removeOutliers'         : removeOutliers,
+    'removeBoutsContainingNanValuesInParametersUsedForClustering' : removeBoutsContainingNanValuesInParametersUsedForClustering
   }
   if int(FreelySwimming):
     clusteringOptions['useAnglesSpeedHeading'] = True
@@ -204,7 +170,7 @@ def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbed
   if int(HeadEmbeded):
     clusteringOptions['useAngles'] = True
   # Applies the clustering
-  [allBouts, classifier] = applyClustering(clusteringOptions, 0, os.path.join(os.path.join(cur_dir_path, 'dataAnalysis'),'resultsClustering/'), self.ZZoutputLocation)
+  [allBouts, classifier] = applyClustering(clusteringOptions, 0, os.path.join(paths.getDataAnalysisFolder(), 'resultsClustering/'), self.ZZoutputLocation)
   # Saves the classifier
   controller.show_frame("AnalysisOutputFolderClustering")
 
