@@ -1,6 +1,10 @@
+from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 
+import zebrazoom.code.util as util
+
+
 def getImageSequential(cap, videoPath, frameNumber, wellNumber, wellPositions, hyperparameters):
   
   minPixelDiffForBackExtract = hyperparameters["minPixelDiffForBackExtract"]
@@ -11,21 +15,24 @@ def getImageSequential(cap, videoPath, frameNumber, wellNumber, wellPositions, h
   lenX = wellPositions[wellNumber]['lengthX']
   lenY = wellPositions[wellNumber]['lengthY']
   
-  # cap = cv2.VideoCapture(videoPath)
-  # cap.set(1, frameNumber)
   ret, frame = cap.read()
   
   while not(ret):
-    print("WARNING: last frame had a value that was too high!")
+    print("WARNING: was not able to extract the frame", str(frameNumber),"in 'getImageSequential'")
     frameNumber = frameNumber - 1
     cap.set(1, frameNumber)
     ret, frame = cap.read()
+    
+  if hyperparameters["invertBlackWhiteOnImages"]:
+    frame = 255 - frame
+  
+  if hyperparameters["imagePreProcessMethod"]:
+    frame = preprocessImage(frame, hyperparameters)
   
   grey = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
   curFrame = grey[ytop:ytop+lenY, xtop:xtop+lenX]
   
   if (debug):
-    cv2.imshow('Frame', curFrame)
-    cv2.waitKey(0)
+    util.showFrame(curFrame, title='Frame')
     
   return curFrame
