@@ -2,6 +2,7 @@ from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
+import zebrazoom.code.util as util
 
 def headEmbededFrameBackExtract(videoPath, background, hyperparameters, frameNumber):
   
@@ -33,16 +34,14 @@ def headEmbededFrameBackExtract(videoPath, background, hyperparameters, frameNum
   thres1 = cv2.cvtColor(thres1, cv2.COLOR_BGR2GRAY)
 
   if (debug):
-    cv2.imshow('thres1', frame)
-    cv2.waitKey(0)
+    util.showFrame(frame, title='thres1')
   
   putToWhite = ( frame.astype('int32') >= (background.astype('int32') + minPixelDiffForBackExtract) )
   # This puts the pixels that belong to a fish to white
   frame[putToWhite] = 255
   
   if (debug):
-    cv2.imshow('thres1', frame)
-    cv2.waitKey(0)
+    util.showFrame(frame, title='thres1')
     # cv2.imshow('thres1', thres1)
     # cv2.waitKey(0)
     
