@@ -2,6 +2,9 @@ from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 
+import zebrazoom.code.util as util
+
+
 def headEmbededFrameSequential(cap, videoPath, frameNumber, hyperparameters):
   
   debug = 0
@@ -9,15 +12,15 @@ def headEmbededFrameSequential(cap, videoPath, frameNumber, hyperparameters):
   ret, frame = cap.read()
   
   while not(ret):
-    print("WARNING: last frame had a value that was too high!")
+    print("WARNING: couldn't read the frameNumber", frameNumber, "for the video", hyperparameters["videoName"])
     frameNumber = frameNumber - 1
     cap.set(1, frameNumber)
     ret, frame = cap.read()
   
-  if hyperparameters["invertBlackWhiteOnImages"]:
+  if ("invertBlackWhiteOnImages" in hyperparameters) and hyperparameters["invertBlackWhiteOnImages"]:
     frame = 255 - frame
   
-  if hyperparameters["imagePreProcessMethod"]:
+  if ("imagePreProcessMethod" in hyperparameters) and hyperparameters["imagePreProcessMethod"]:
     frame = preprocessImage(frame, hyperparameters)
   
   kernel = np.ones((8,8),np.float32)/25
@@ -28,10 +31,8 @@ def headEmbededFrameSequential(cap, videoPath, frameNumber, hyperparameters):
   frame = 255 - frame
   
   if (debug):
-    cv2.imshow('thres1', frame)
-    cv2.waitKey(0)
-    cv2.imshow('thres1', thres1)
-    cv2.waitKey(0)
+    util.showFrame(frame, title='thres1')
+    util.showFrame(thres1, title='thres1')
     
   frame  = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
   thres1 = cv2.cvtColor(thres1, cv2.COLOR_BGR2GRAY)
