@@ -2,6 +2,9 @@ from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 
+import zebrazoom.code.util as util
+
+
 def headEmbededFrameSequentialBackExtract(cap, videoPath, background, hyperparameters, frameNumber):
   
   minPixelDiffForBackExtract = hyperparameters["minPixelDiffForBackExtract"]
@@ -10,15 +13,15 @@ def headEmbededFrameSequentialBackExtract(cap, videoPath, background, hyperparam
   ret, frame = cap.read()
   
   while not(ret):
-    print("WARNING: last frame had a value that was too high!")
+    print("WARNING: couldn't read the frameNumber", frameNumber, "for the video", hyperparameters["videoName"])
     frameNumber = frameNumber - 1
     cap.set(1, frameNumber)
     ret, frame = cap.read()
     
-  if hyperparameters["invertBlackWhiteOnImages"]:
+  if ("invertBlackWhiteOnImages" in hyperparameters) and hyperparameters["invertBlackWhiteOnImages"]:
     frame = 255 - frame
     
-  if hyperparameters["imagePreProcessMethod"]:
+  if ("imagePreProcessMethod" in hyperparameters) and hyperparameters["imagePreProcessMethod"]:
     frame = preprocessImage(frame, hyperparameters)
   
   kernel = np.ones((8,8),np.float32)/25
@@ -29,16 +32,14 @@ def headEmbededFrameSequentialBackExtract(cap, videoPath, background, hyperparam
   thres1 = cv2.cvtColor(thres1, cv2.COLOR_BGR2GRAY)
 
   if (debug):
-    cv2.imshow('thres1', frame)
-    cv2.waitKey(0)
+    util.showFrame(frame, title='thres1')
   
   putToWhite = ( frame.astype('int32') >= (background.astype('int32') + minPixelDiffForBackExtract) )
   # This puts the pixels that belong to a fish to white
   frame[putToWhite] = 255
   
   if (debug):
-    cv2.imshow('thres1', frame)
-    cv2.waitKey(0)
+    util.showFrame(frame, title='thres1')
     # cv2.imshow('thres1', thres1)
     # cv2.waitKey(0)
     
