@@ -5,15 +5,11 @@ import numpy as np
 import sys
 import os
 import cv2
-from pathlib import Path
 
-try:
-  from PyQt6.QtCore import Qt, QSize, QTimer
-  from PyQt6.QtWidgets import QLabel, QSlider, QVBoxLayout
-except ImportError:
-  from PyQt5.QtCore import Qt, QSize, QTimer
-  from PyQt5.QtWidgets import QLabel, QSlider, QVBoxLayout
+from PyQt5.QtCore import Qt, QSize, QTimer
+from PyQt5.QtWidgets import QLabel, QSlider, QVBoxLayout
 
+import zebrazoom.code.paths as paths
 import zebrazoom.code.util as util
 
 
@@ -25,12 +21,10 @@ def readValidationVideo(videoPath, folderName, configFilePath, numWell, numAnima
   s5  = ".avi"
   s5b = ".txt"
 
-  cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-  initialPath  = Path(cur_dir_path)
-  initialPath  = initialPath.parent
-  initialPath  = os.path.join(initialPath, s1)
   if len(ZZoutputLocation):
     initialPath = ZZoutputLocation
+  else:
+    initialPath = paths.getDefaultZZoutputFolder()
 
   with open(os.path.join(initialPath, os.path.join(s2, 'configUsed.json'))) as f:
     configTemp = json.load(f)
@@ -203,26 +197,31 @@ def readValidationVideo(videoPath, folderName, configFilePath, numWell, numAnima
 
     if lengthX > 100 and lengthY > 100:
       font = cv2.FONT_HERSHEY_SIMPLEX
-      cv2.putText(img,str(l + supstruct["firstFrame"] - 1),(int(lengthX-110), int(lengthY-30)),font,1,(0,255,0))
+      cv2.putText(img,str(l + supstruct["firstFrame"]),(int(lengthX-110), int(lengthY-30)),font,1,(0,255,0))
     else:
       blank_image = np.zeros((len(img)+30, len(img[0]), 3), np.uint8)
       blank_image[0:len(img), 0:len(img[0])] = img
       img = blank_image
       font = cv2.FONT_HERSHEY_SIMPLEX
-      cv2.putText(img, str(l + supstruct["firstFrame"] - 1), (int(0), int(lengthY+25)), font, 1, (0,255,0))
+      cv2.putText(img, str(l + supstruct["firstFrame"]), (int(0), int(lengthY+25)), font, 1, (0,255,0))
 
     return img
 
   layout = QVBoxLayout()
 
   video = QLabel()
-  layout.addWidget(video, alignment=Qt.AlignmentFlag.AlignCenter)
+  layout.addWidget(video, stretch=1)
 
   frameSlider = QSlider(Qt.Orientation.Horizontal)
+  frameSlider.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
+  frameSlider.setPageStep(50)
   frameSlider.setRange(0, max_l - 1)
   frameSlider.setValue(l)
   frameSlider.valueChanged.connect(lambda: util.setPixmapFromCv(getFrame(), video))
   layout.addWidget(frameSlider)
+  shortcutsLabel = QLabel("Left Arrow, Right Arrow, Page Up, Page Down, Home and End keys can be used to navigate through the video.")
+  shortcutsLabel.setWordWrap(True)
+  layout.addWidget(shortcutsLabel)
 
   stopTimer = True
   timer = QTimer()
