@@ -5,6 +5,7 @@ import math
 import json
 import sys
 from scipy import interpolate
+import zebrazoom.code.util as util
 from zebrazoom.code.getImage.getForegroundImage import getForegroundImage
 from zebrazoom.code.getImage.headEmbededFrame import headEmbededFrame
 from scipy.interpolate import UnivariateSpline
@@ -165,7 +166,6 @@ def findTheTwoSides(headPosition, bodyContour, dst, hyperparameters):
   if False:
     cv2.circle(dst, (pt1[0],pt1[1]), 1, (0, 0, 255), -1)
     cv2.circle(dst, (pt2[0],pt2[1]), 1, (0, 0, 255), -1)
-    cv2.imshow('Frame', dst)
-    cv2.waitKey(0)
+    util.showFrame(dst, title='Frame')
   
   return res
